==> icevision-0.7.0rc3.tar.gz: icevision-0.7.0rc3/icevision/models/ross/efficientdet/backbones.py <==
__all__ = [
    "tf_lite0",
    "tf_lite1",
    "tf_lite2",
    "tf_lite3",
    "tf_d0",
    "tf_d1",
    "tf_d2",
    "tf_d3",
    "tf_d4",
    "tf_d5",
    "tf_d6",
    "tf_d7",
    "tf_d7x",
    "d0",
    "d1",
    "d2",
    "d3",
    "d4",
    "d5",
    "d6",
    "d7",
    "d7x",
]

from icevision.models.ross.efficientdet.utils import *


tf_lite0 = EfficientDetBackboneConfig(model_name="tf_efficientdet_lite0")
tf_lite1 = EfficientDetBackboneConfig(model_name="tf_efficientdet_lite1")
tf_lite2 = EfficientDetBackboneConfig(model_name="tf_efficientdet_lite2")
tf_lite3 = EfficientDetBackboneConfig(model_name="tf_efficientdet_lite3")

tf_d0 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d0")
tf_d1 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d1")
tf_d2 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d2")
tf_d3 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d3")
tf_d4 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d4")
tf_d5 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d5")
tf_d6 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d6")
tf_d7 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d7")
tf_d7x = EfficientDetBackboneConfig(model_name="tf_efficientdet_d7x")

d0 = EfficientDetBackboneConfig(model_name="efficientdet_d0")
d1 = EfficientDetBackboneConfig(model_name="efficientdet_d1")
d2 = EfficientDetBackboneConfig(model_name="efficientdet_d2")
d3 = EfficientDetBackboneConfig(model_name="efficientdet_d3")
d4 = EfficientDetBackboneConfig(model_name="efficientdet_d4")
d5 = EfficientDetBackboneConfig(model_name="efficientdet_d5")
d6 = EfficientDetBackboneConfig(model_name="efficientdet_d6")
d7 = EfficientDetBackboneConfig(model_name="efficientdet_d7")
d7x = EfficientDetBackboneConfig(model_name="efficientdet_d7x")

==> icevision-0.12.0.tar.gz: icevision-0.12.0/icevision/models/ross/efficientdet/backbones.py <==
__all__ = [
    "tf_lite0",
    "tf_lite1",
    "tf_lite2",
    "tf_lite3",
    "tf_d0",
    "tf_d1",
    "tf_d2",
    "tf_d3",
    "tf_d4",
    "tf_d5",
    "tf_d6",
    "tf_d7",
    "tf_d7x",
    "d0",
    "d1",
    "d2",
    "d3",
    "d4",
    "d5",
    "d6",
    "d7",
    "d7x",
    "tf_d0_ap",
    "tf_d1_ap",
    "tf_d2_ap",
    "tf_d3_ap",
    "tf_d4_ap",
    "tf_d5_ap",
]

from icevision.models.ross.efficientdet.utils import *


tf_lite0 = EfficientDetBackboneConfig(model_name="tf_efficientdet_lite0")
tf_lite1 = EfficientDetBackboneConfig(model_name="tf_efficientdet_lite1")
tf_lite2 = EfficientDetBackboneConfig(model_name="tf_efficientdet_lite2")
tf_lite3 = EfficientDetBackboneConfig(model_name="tf_efficientdet_lite3")

tf_d0 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d0")
tf_d1 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d1")
tf_d2 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d2")
tf_d3 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d3")
tf_d4 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d4")
tf_d5 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d5")
tf_d6 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d6")
tf_d7 = EfficientDetBackboneConfig(model_name="tf_efficientdet_d7")
tf_d7x = EfficientDetBackboneConfig(model_name="tf_efficientdet_d7x")

d0 = EfficientDetBackboneConfig(model_name="efficientdet_d0")
d1 = EfficientDetBackboneConfig(model_name="efficientdet_d1")
d2 = EfficientDetBackboneConfig(model_name="efficientdet_d2")
d3 = EfficientDetBackboneConfig(model_name="efficientdet_d3")
d4 = EfficientDetBackboneConfig(model_name="efficientdet_d4")
d5 = EfficientDetBackboneConfig(model_name="efficientdet_d5")
d6 = EfficientDetBackboneConfig(model_name="efficientdet_d6")
d7 = EfficientDetBackboneConfig(model_name="efficientdet_d7")
d7x = EfficientDetBackboneConfig(model_name="efficientdet_d7x")

tf_d0_ap = EfficientDetBackboneConfig(model_name="tf_efficientdet_d0_ap")
tf_d1_ap = EfficientDetBackboneConfig(model_name="tf_efficientdet_d1_ap")
tf_d2_ap = EfficientDetBackboneConfig(model_name="tf_efficientdet_d2_ap")
tf_d3_ap = EfficientDetBackboneConfig(model_name="tf_efficientdet_d3_ap")
tf_d4_ap = EfficientDetBackboneConfig(model_name="tf_efficientdet_d4_ap")
tf_d5_ap = EfficientDetBackboneConfig(model_name="tf_efficientdet_d5_ap")
